@@ -28,7 +28,7 @@
 #include "e-book-backend-sexp.h"
 
 struct _EBookBackendCachePrivate {
-	char *uri;
+	gchar *uri;
 };
 
 /* Property IDs */
@@ -39,11 +39,11 @@ enum {
 
 static GObjectClass *parent_class = NULL;
 
-static char *
-get_filename_from_uri (const char *uri)
+static gchar *
+get_filename_from_uri (const gchar *uri)
 {
-	char *mangled_uri, *filename;
-	int i;
+	gchar *mangled_uri, *filename;
+	gint i;
 
 	/* mangle the URI to not contain invalid characters */
 	mangled_uri = g_strdup (uri);
@@ -70,7 +70,7 @@ e_book_backend_cache_set_property (GObject *object, guint property_id, const GVa
 {
 	EBookBackendCache *cache;
 	EBookBackendCachePrivate *priv;
-	char *cache_file;
+	gchar *cache_file;
 
 	cache = E_BOOK_BACKEND_CACHE (object);
 	priv = cache->priv;
@@ -111,7 +111,6 @@ e_book_backend_cache_get_property (GObject *object, guint property_id, GValue *v
 	}
 }
 
-
 static void
 e_book_backend_cache_finalize (GObject *object)
 {
@@ -127,7 +126,6 @@ e_book_backend_cache_finalize (GObject *object)
 			priv->uri = NULL;
 		}
 
-
 		g_free (priv);
 		cache->priv = NULL;
 	}
@@ -141,8 +139,8 @@ e_book_backend_cache_constructor (GType type,
                                  GObjectConstructParam *construct_properties)
 {
 	GObject *obj;
-	const char *uri;
-	char *cache_file;
+	const gchar *uri;
+	gchar *cache_file;
 
 	/* Invoke parent constructor. */
 	obj = parent_class->constructor (type,
@@ -191,7 +189,6 @@ e_book_backend_cache_init (EBookBackendCache *cache)
 
 }
 
-
 GType
 e_book_backend_cache_get_type (void)
 {
@@ -224,11 +221,11 @@ e_book_backend_cache_get_type (void)
  * Return value: A new #EBookBackendCache.
  */
 EBookBackendCache *
-e_book_backend_cache_new (const char *uri)
+e_book_backend_cache_new (const gchar *uri)
 {
 	EBookBackendCache *cache;
 
-       	cache = g_object_new (E_TYPE_BOOK_BACKEND_CACHE, "uri", uri, NULL);
+	cache = g_object_new (E_TYPE_BOOK_BACKEND_CACHE, "uri", uri, NULL);
 
         return cache;
 }
@@ -245,9 +242,9 @@ e_book_backend_cache_new (const char *uri)
  * Return value: A cached #EContact, or %NULL if @uid is not cached.
  **/
 EContact *
-e_book_backend_cache_get_contact (EBookBackendCache *cache, const char *uid)
+e_book_backend_cache_get_contact (EBookBackendCache *cache, const gchar *uid)
 {
-	const char *vcard_str;
+	const gchar *vcard_str;
 	EContact *contact = NULL;
 
 	g_return_val_if_fail (E_IS_BOOK_BACKEND_CACHE (cache), NULL);
@@ -259,7 +256,6 @@ e_book_backend_cache_get_contact (EBookBackendCache *cache, const char *uid)
 
 	}
 
-
 	return contact;
 }
 
@@ -276,14 +272,13 @@ gboolean
 e_book_backend_cache_add_contact (EBookBackendCache *cache,
 				   EContact *contact)
 {
-	char *vcard_str;
-	const char *uid;
+	gchar *vcard_str;
+	const gchar *uid;
 	gboolean retval;
 	EBookBackendCachePrivate *priv;
 
 	g_return_val_if_fail (E_IS_BOOK_BACKEND_CACHE (cache), FALSE);
 
-
 	priv = cache->priv;
 
 	uid = e_contact_get_const (contact, E_CONTACT_UID);
@@ -310,7 +305,7 @@ e_book_backend_cache_add_contact (EBookBackendCache *cache,
  **/
 gboolean
 e_book_backend_cache_remove_contact (EBookBackendCache *cache,
-				    const char *uid)
+				    const gchar *uid)
 
 {
 	gboolean retval;
@@ -321,14 +316,12 @@ e_book_backend_cache_remove_contact (EBookBackendCache *cache,
 
 	priv = cache->priv;
 
-
 	if (!e_file_cache_get_object (E_FILE_CACHE (cache), uid)) {
 		return FALSE;
 	}
 
 	retval = e_file_cache_remove_object (E_FILE_CACHE (cache), uid);
 
-
 	return retval;
 }
 
@@ -342,7 +335,7 @@ e_book_backend_cache_remove_contact (EBookBackendCache *cache,
  * Return value: %TRUE if the cache contains the contact, %FALSE otherwise.
  **/
 gboolean
-e_book_backend_cache_check_contact (EBookBackendCache *cache, const char *uid)
+e_book_backend_cache_check_contact (EBookBackendCache *cache, const gchar *uid)
 {
 
 	gboolean retval;
@@ -371,14 +364,14 @@ e_book_backend_cache_check_contact (EBookBackendCache *cache, const char *uid)
  * Return value: A #GList of pointers to #EContact.
  **/
 GList *
-e_book_backend_cache_get_contacts (EBookBackendCache *cache, const char *query)
+e_book_backend_cache_get_contacts (EBookBackendCache *cache, const gchar *query)
 {
-        char *vcard_str;
+        gchar *vcard_str;
         GSList *l, *lcache;
 	GList *list = NULL;
 	EContact *contact;
         EBookBackendSExp *sexp = NULL;
-	const char *uid;
+	const gchar *uid;
 
 	g_return_val_if_fail (E_IS_BOOK_BACKEND_CACHE (cache), NULL);
 	if (query) {
@@ -387,10 +380,9 @@ e_book_backend_cache_get_contacts (EBookBackendCache *cache, const char *query)
 			return NULL;
 	}
 
-
         lcache = l = e_file_cache_get_objects (E_FILE_CACHE (cache));
 
-        for ( ; l != NULL; l = g_slist_next (l)) {
+        for (; l != NULL; l = g_slist_next (l)) {
                 vcard_str = l->data;
                 if (vcard_str && !strncmp (vcard_str, "BEGIN:VCARD", 11)) {
                         contact = e_contact_new_from_vcard (vcard_str);
@@ -422,7 +414,7 @@ e_book_backend_cache_get_contacts (EBookBackendCache *cache, const char *query)
  * Return value: A #GPtrArray of pointers to contact ID strings.
  **/
 GPtrArray *
-e_book_backend_cache_search (EBookBackendCache *cache, const char *query)
+e_book_backend_cache_search (EBookBackendCache *cache, const gchar *query)
 {
 	GList *matching_contacts, *temp;
 	GPtrArray *ptr_array;
@@ -449,9 +441,9 @@ e_book_backend_cache_search (EBookBackendCache *cache, const char *query)
  * Return value: %TRUE if cache exists, %FALSE if not.
  **/
 gboolean
-e_book_backend_cache_exists (const char *uri)
+e_book_backend_cache_exists (const gchar *uri)
 {
-	char *file_name;
+	gchar *file_name;
 	gboolean exists = FALSE;
 	file_name = get_filename_from_uri (uri);
 
@@ -473,7 +465,7 @@ e_book_backend_cache_exists (const char *uri)
 void
 e_book_backend_cache_set_populated (EBookBackendCache *cache)
 {
-  	g_return_if_fail (E_IS_BOOK_BACKEND_CACHE (cache));
+	g_return_if_fail (E_IS_BOOK_BACKEND_CACHE (cache));
 	e_file_cache_add_object (E_FILE_CACHE (cache), "populated", "TRUE");
 
 }
@@ -489,20 +481,20 @@ e_book_backend_cache_set_populated (EBookBackendCache *cache)
 gboolean
 e_book_backend_cache_is_populated (EBookBackendCache *cache)
 {
-  	g_return_val_if_fail (E_IS_BOOK_BACKEND_CACHE (cache), FALSE);
+	g_return_val_if_fail (E_IS_BOOK_BACKEND_CACHE (cache), FALSE);
 	if (e_file_cache_get_object (E_FILE_CACHE (cache), "populated"))
 		return TRUE;
 	return FALSE;
 }
 
 void
-e_book_backend_cache_set_time (EBookBackendCache *cache, const char *t)
+e_book_backend_cache_set_time (EBookBackendCache *cache, const gchar *t)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND_CACHE (cache));
 	e_file_cache_add_object (E_FILE_CACHE (cache), "last_update_time", t);
 }
 
-char *
+gchar *
 e_book_backend_cache_get_time (EBookBackendCache *cache)
 {
 	g_return_val_if_fail (E_IS_BOOK_BACKEND_CACHE (cache), NULL);
